==> ds-bootstrap-0.3.0-alpha.1.tgz: package/esm/Widgets/TextField/TextField.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
const _excluded = ["schema"],
      _excluded2 = ["schema"];
import React from 'react';
import { TransTitle } from '@ui-schema/ui-schema';
import { ValidityHelperText } from '../../Component/LocaleHelperText/LocaleHelperText';
import { useUID } from 'react-uid';
export const convertStringToNumber = (value, type) => {
  if (type === 'number') {
    if (isNaN(value * 1)) {
      console.error('Invalid Type: input not a number in');
      return;
    }

    return value === '' ? '' : value * 1;
  }

  return value;
};

const StringRenderer = ({
  ownKey,
  schema,
  value,
  multiline = false,
  onChange,
  storeKeys,
  showValidity,
  required,
  errors,
  type,
  rows
}) => {
  const format = schema.get('format');
  const uid = useUID();
  let Renderer = 'input';

  if (multiline) {
    Renderer = 'textarea';
  }

  let classFormGroup = ['form-group'];
  let classFormControl = ['form-control'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classFormGroup.push('was-validated');
  }

  return /*#__PURE__*/React.createElement("div", {
    className: classFormGroup.join(' ')
  }, /*#__PURE__*/React.createElement("label", {
    htmlFor: 'uis-' + uid
  }, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  })), /*#__PURE__*/React.createElement(Renderer, {
    className: classFormControl.join(' '),
    type: format || type,
    required: required,
    rows: rows,
    value: typeof value !== 'undefined' ? value : '',
    onChange: e => {
      const val = e.target.value;
      onChange(storeKeys, ['value'], {
        type: 'update',
        update: () => ({
          value: convertStringToNumber(val, schema.get('type'))
        }),
        schema,
        required
      });
    }
  }), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

const TextRenderer = _ref => {
  let {
    schema
  } = _ref,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    rows: schema.getIn(['view', 'rows']),
    multiline: true
  }));
};

const NumberRenderer = _ref2 => {
  let {
    schema
  } = _ref2,
      props = _objectWithoutProperties(_ref2, _excluded2);

  return /*#__PURE__*/React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    type: 'number'
  }));
};

export { StringRenderer, NumberRenderer, TextRenderer };

==> ds-bootstrap-0.4.0-alpha.1.tgz: package/esm/Widgets/TextField/TextField.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
const _excluded = ["schema"],
      _excluded2 = ["schema"];
import React from 'react';
import { TransTitle } from '@ui-schema/ui-schema';
import { ValidityHelperText } from '../../Component/LocaleHelperText/LocaleHelperText';
import { useUID } from 'react-uid';
export const convertStringToNumber = (value, type) => {
  if (type === 'number') {
    if (isNaN(value * 1)) {
      console.error('Invalid Type: input not a number in');
      return;
    }

    return value === '' ? '' : value * 1;
  }

  return value;
};

const StringRenderer = ({
  schema,
  value,
  multiline = false,
  onChange,
  storeKeys,
  showValidity,
  required,
  errors,
  type,
  rows
}) => {
  const format = schema.get('format');
  const uid = useUID();
  let Renderer = 'input';

  if (multiline) {
    Renderer = 'textarea';
  }

  let classFormGroup = ['form-group'];
  let classFormControl = ['form-control'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classFormGroup.push('was-validated');
  }

  return /*#__PURE__*/React.createElement("div", {
    className: classFormGroup.join(' ')
  }, /*#__PURE__*/React.createElement("label", {
    htmlFor: 'uis-' + uid
  }, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys
  })), /*#__PURE__*/React.createElement(Renderer, {
    className: classFormControl.join(' '),
    type: format || type,
    required: required,
    rows: rows,
    value: typeof value !== 'undefined' ? value : '',
    onChange: e => {
      const val = e.target.value;
      onChange({
        storeKeys,
        scopes: ['value'],
        type: 'set',
        data: {
          value: convertStringToNumber(val, schema.get('type'))
        },
        schema,
        required
      });
    }
  }), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

const TextRenderer = _ref => {
  let {
    schema
  } = _ref,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    rows: schema.getIn(['view', 'rows']),
    multiline: true
  }));
};

const NumberRenderer = _ref2 => {
  let {
    schema
  } = _ref2,
      props = _objectWithoutProperties(_ref2, _excluded2);

  return /*#__PURE__*/React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    type: 'number'
  }));
};

export { StringRenderer, NumberRenderer, TextRenderer };
